<?php

/**
 * Plugin Name:       EventScout
 * Description:       The complete event management solution for WordPress.
 * Version:           1.0.0
 * Author:            emazharulislam
 * Author URI:        https://profiles.wordpress.org/emazharulislam/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       event-scout
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'EVENT_SCOUT_VERSION', '1.0.0' );
define( 'EVENT_SCOUT_FILE', __FILE__ );
define( 'EVENT_SCOUT_ROOT_PATH', plugin_dir_path( __FILE__ ) );
define( 'EVENT_SCOUT_ROOT_URL', plugins_url( '/', __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-event-scout-activator.php
 */
function activate_event_scout() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-event-scout-activator.php';
	event_scout_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-event-scout-deactivator.php
 */
function deactivate_event_scout() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-event-scout-deactivator.php';
	event_scout_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_event_scout' );
register_deactivation_hook( __FILE__, 'deactivate_event_scout' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-event-scout.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */

function run_event_scout() {

	$plugin = new event_scout();
	$plugin->run();

}


add_filter( "template_include", function( $template ) {
	$post_type = get_query_var( 'post_type' );

	if ( 'event_scout' != $post_type ) {
		return $template;
	}

	$theme_file_path = get_stylesheet_directory() . '/event_scout/single-event_scout.php';

	if ( file_exists( $theme_file_path ) ) {
		return $theme_file_path;
	}

	$plugin_file_path = EVENT_SCOUT_ROOT_PATH . 'templates/single-event_scout.php';

	if ( file_exists( $plugin_file_path ) ) {
		return $plugin_file_path;
	}

	return $template;
});



run_event_scout();
