<?php
/*
| -------------------------------------------
| Manage post type
|
| Add post type, Create metabox, Save metabox data
| -------------------------------------------
*/
class Post_Type {

	/**
	 * Constructor for the Post_Type class
	 */
	public function __construct() {

		$this->create_post_type();

		$this->create_taxonomy();

		add_action( 'add_meta_boxes_event_scout', [ $this, 'create_metaboxes' ] );

		add_action( 'save_post_event_scout', [ $this, 'save_metabox' ], 20, 2 );

	}

	/**
	 * Register a event_scout post type.
	 *
	 * @return  void
	 */
	private function create_post_type() {
		$labels = [
			'name'               => _x( 'Events', 'post type general name', 'event-scout' ),
			'singular_name'      => _x( 'Event', 'post type singular name', 'event-scout' ),
			'menu_name'          => _x( 'Events', 'admin menu', 'event-scout' ),
			'name_admin_bar'     => _x( 'Event', 'add new on admin bar', 'event-scout' ),
			'add_new'            => _x( 'Add New Event', 'book', 'event-scout' ),
			'add_new_item'       => __( 'Add New Event', 'event-scout' ),
			'new_item'           => __( 'New Event', 'event-scout' ),
			'edit_item'          => __( 'Edit Event', 'event-scout' ),
			'view_item'          => __( 'View Event', 'event-scout' ),
			'all_items'          => __( 'All Events', 'event-scout' ),
			'search_items'       => __( 'Search Events', 'event-scout' ),
			'parent_item_colon'  => __( 'Parent Events:', 'event-scout' ),
			'not_found'          => __( 'No Event found.', 'event-scout' ),
			'not_found_in_trash' => __( 'No Event found in Trash.', 'event-scout' ),
		];

		$args = [
			'labels'             => $labels,
			'description'        => __( 'Description of Events.', 'event-scout' ),
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => [ 'slug' => 'events' ],
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => false,
			'menu_position'      => null,
			'supports'           => [ 'title', 'editor', 'thumbnail' ],
			'show_in_rest'       => true,
			'menu_icon'          => 'dashicons-calendar',
		];

		register_post_type( 'event_scout', $args );
	}


	/**
	 * Add event_scout_category custom taxonomy
	 *
	 * @return  void
	 */
	private function create_taxonomy() {
		$category_labels = [
			'name'              => _x( 'Product Categories', 'taxonomy general name', 'event-scout' ),
			'singular_name'     => _x( 'Category', 'taxonomy singular name', 'event-scout' ),
			'search_items'      => __( 'Search Categories', 'event-scout' ),
			'all_items'         => __( 'All Categories', 'event-scout' ),
			'parent_item'       => __( 'Parent Category', 'event-scout' ),
			'parent_item_colon' => __( 'Parent Category:', 'event-scout' ),
			'edit_item'         => __( 'Edit Category', 'event-scout' ),
			'update_item'       => __( 'Update Category', 'event-scout' ),
			'add_new_item'      => __( 'Add New Category', 'event-scout' ),
			'new_item_name'     => __( 'New Category Name', 'event-scout' ),
			'menu_name'         => __( 'Categories', 'event-scout' ),
		];

		$category_args = [
			'hierarchical'      => true,
			'labels'            => $category_labels,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'event-categories' ),
			'show_in_rest'      => true,
		];

		$tag_labels = [
			'name'              => _x( 'Product Tags', 'taxonomy general name', 'event-scout' ),
			'singular_name'     => _x( 'Tag', 'taxonomy singular name', 'event-scout' ),
			'search_items'      => __( 'Search Tags', 'event-scout' ),
			'all_items'         => __( 'All Tags', 'event-scout' ),
			'parent_item'       => __( 'Parent Tag', 'event-scout' ),
			'parent_item_colon' => __( 'Parent Tag:', 'event-scout' ),
			'edit_item'         => __( 'Edit Tag', 'event-scout' ),
			'update_item'       => __( 'Update Tag', 'event-scout' ),
			'add_new_item'      => __( 'Add New Tag', 'event-scout' ),
			'new_item_name'     => __( 'New Tag Name', 'event-scout' ),
			'menu_name'         => __( 'Tags', 'event-scout' ),
		];

		$tag_args = [
			'hierarchical'      => true,
			'labels'            => $tag_labels,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'event-tags' ),
			'show_in_rest'      => true,
		];

		register_taxonomy( 'event_scout_category', [ 'event_scout' ], $category_args );
		register_taxonomy( 'event_scout_tag', [ 'event_scout' ], $tag_args );
	}

	/**
	 * Metaboxes of `event_scout` post type
	 */
	public function create_metaboxes() {

		add_meta_box(
			'event-details',
			'Event Details',
			[ $this, 'render_details_metabox' ],
			'event_scout',
			'advanced',
			'default'
		);

	}

	/**
	 * Renders the meta box of event details.
	 */
	public function render_details_metabox( $post ) {
		$meta = get_post_custom( $post->ID );
		$location = ! isset( $meta['event_location'][0] ) ? '' : $meta['event_location'][0];
		$date = ! isset( $meta['event_date'][0] ) ? '' : $meta['event_date'][0];

		wp_nonce_field( basename( __FILE__ ), 'event_details_fields' );
	?>

	<table class="form-table">
		<tr>
			<td class="event_meta_box_td" colspan="2">
				<label for="event_location"><?php _e( 'Location', 'event-scout' ); ?>
				</label>
			</td>
			<td colspan="4">
				<input type="text" id="event_location" name="event_location" class="regular-text" value="<?php echo $location; ?>">
				<p class="description"><?php _e( 'E.g. Mirpur, Dhaka, Bangladesh', 'event-scout' ); ?></p>
			</td>
		</tr>

		<tr>
			<td class="event_meta_box_td" colspan="2">
				<label for="event_date"><?php _e( 'Event Date', 'event-scout' ); ?>
				</label>
			</td>
			<td colspan="4">
				<input type="text" id="event_date" name="event_date" class="events_datepicker regular-text" value="<?php echo $date; ?>">
				<p class="description"><?php _e( 'E.g. 01/01/2019', 'event-scout' ); ?></p>
			</td>
		</tr>

	</table>

	<?php

	}

	/**
	 * Save metabox data
	 */
	public function save_metabox( $post_id ) {

		global $post;

		// Verify nonce
		if ( ! isset( $_POST['event_details_fields'] ) || ! wp_verify_nonce( $_POST['event_details_fields'], basename(__FILE__) ) ) {
			return $post_id;
		}

		// Check if not an autosave.
		if ( wp_is_post_autosave( $post_id ) ) {
			return;
		}

		// Check if not a revision.
		if ( wp_is_post_revision( $post_id ) ) {
			return;
		}

		// Check permissions
		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return $post_id;
		}

		$meta['event_location'] = ( isset( $_POST['event_location'] ) ? sanitize_text_field( $_POST['event_location'] ) : '' );
		$meta['event_date'] = ( isset( $_POST['event_date'] ) ? strtotime( $_POST['event_date'] ) : '' );

		foreach ( $meta as $key => $value ) {
			update_post_meta( $post->ID, $key, $value );
		}

	}

}
